@@ -166,8 +166,8 @@ FORCE_DELETE_PLUGIN = (
 )
 
 FORCE_DELETE_BLUEPRINT = (
-    "Delete the blueprint even if there are deployments which are currently "
-    "using it"
+    "Delete the blueprint regardless of it's state and even if there are "
+    "deployments which are currently using it"
 )
 
 FORCE_TEARDOWN = "This is mandatory for performing the teardown"
