@@ -1,5 +1,5 @@
 ########
-# Copyright (c) 2014 GigaSpaces Technologies Ltd. All rights reserved
+# Copyright (c) 2014-2019 Cloudify Platform Ltd. All rights reserved
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,18 +14,21 @@
 # limitations under the License.
 ############
 
+import json
+
 from cloudify_rest_client.exceptions import CloudifyClientError, \
     UserUnauthorizedError
 
-from ..table import print_data
 from ..cli import cfy
 from ..env import profile
+from ..table import print_data
+from ..logger import CloudifyJSONEncoder, output, get_global_json_output
 
 STATUS_COLUMNS = ['service', 'status']
 
 
 @cfy.command(name='status', short_help="Show manager status [manager only]")
-@cfy.options.verbose()
+@cfy.options.common_options
 @cfy.assert_manager_active()
 @cfy.pass_client()
 @cfy.pass_logger
@@ -47,23 +50,16 @@ def status(logger, client):
             rest_host))
         return False
 
-    # manager_ip can change if we're using a cluster client and failed over
-    # while getting the status
-    actual_ip = profile.manager_ip
-    if actual_ip != rest_host:
-        logger.info('Retrieved manager services status... [ip={0}]'.format(
-            actual_ip))
-
-    services = []
-    for service in status_result['services']:
-        state = service['instances'][0]['state'] \
-            if 'instances' in service and \
-               len(service['instances']) > 0 else 'unknown'
-        services.append({
-            'service': service['display_name'].ljust(30),
-            'status': state
-        })
-    print_data(STATUS_COLUMNS, services, 'Services:')
+    if get_global_json_output():
+        output(json.dumps(status_result, cls=CloudifyJSONEncoder))
+    else:
+        services = []
+        for display_name, service in status_result['services'].items():
+            services.append({
+                'service': display_name.ljust(30),
+                'status': service.get('status')
+            })
+        print_data(STATUS_COLUMNS, services, 'Services:')
 
     maintenance_status = maintenance_response.status
     if maintenance_status != 'deactivated':
