@@ -24,7 +24,6 @@ from .exceptions import (ExecutionTimeoutError,
 
 
 WAIT_FOR_EXECUTION_SLEEP_INTERVAL = 1
-WAIT_FOR_LAST_MESSAGES_SLEEP_INTERVAL = 3
 WORKFLOW_END_TYPES = {u'workflow_succeeded', u'workflow_failed',
                       u'workflow_cancelled'}
 
@@ -156,35 +155,6 @@ def get_deployment_environment_creation_execution(client, deployment_id):
         'execution. Available executions: {0}'.format(executions))
 
 
-class EventsWatcher(object):
-    """Wraps an event_handler function, examines events to check if an
-    workflow execution finished has arrived.
-
-    This will increase its.end_logs_received instance attribute by 1,
-    when it receives an event of type workflow_succeeded, workflow_cancelled
-    or workflow_failed.
-
-    :ivar end_logs_received: how many was a "workflow execution finished"
-        events have been seen?
-    :vartype end_logs_received: int
-    """
-
-    def __init__(self, events_handler=None):
-        self._events_handler = events_handler
-        self.end_logs_received = 0
-
-    def __call__(self, events):
-        if self._events_handler is not None:
-            self._events_handler(events)
-
-        if any(self._is_end_event(evt) for evt in events):
-            self.end_logs_received += 1
-
-    def _is_end_event(self, event):
-        """Is event a 'workflow execution finished' event?"""
-        return event.get('event_type') in WORKFLOW_END_TYPES
-
-
 def wait_for_execution(client,
                        execution,
                        events_handler=None,
@@ -206,13 +176,7 @@ def wait_for_execution(client,
                                             from_datetime=from_datetime)
 
     # Poll for execution status and execution logs, until execution ends
-    # and we receive an event of type in WORKFLOW_END_TYPES
     execution_ended = False
-    events_watcher = EventsWatcher(events_handler)
-
-    # did we already see the execution status change, and are only waiting
-    # for additional logs now?
-    waiting_for_logs = False
 
     while True:
         if timeout is not None:
@@ -231,29 +195,12 @@ def wait_for_execution(client,
             execution_ended = execution.status in Execution.END_STATES
 
         events_fetcher.fetch_and_process_events(
-            events_handler=events_watcher, timeout=timeout)
+            events_handler=events_handler, timeout=timeout)
 
-        if execution_ended and events_watcher.end_logs_received > 0:
+        if execution_ended:
             break
 
-        # if the execution ended, wait one iteration for additional logs
-        sleep_interval = WAIT_FOR_EXECUTION_SLEEP_INTERVAL
-        if execution_ended:
-            if waiting_for_logs:
-                if logger:
-                    logger.info('Execution ended, but no end log message '
-                                'received. Some logs might not have been '
-                                'displayed.')
-                break
-            else:
-                sleep_interval = WAIT_FOR_LAST_MESSAGES_SLEEP_INTERVAL
-                if logger:
-                    logger.info('Execution ended, waiting {0} seconds for '
-                                'additional log messages'
-                                .format(sleep_interval))
-                waiting_for_logs = True
-
-        time.sleep(sleep_interval)
+        time.sleep(WAIT_FOR_EXECUTION_SLEEP_INTERVAL)
 
     return execution
 
@@ -283,14 +230,7 @@ def wait_for_execution_group(client,
         from_datetime=from_datetime)
 
     # Poll for execution status and execution logs, until execution ends
-    # and we receive an event of type in WORKFLOW_END_TYPES
-    execution_amount = len(execution_group.execution_ids)
     group_finished = False
-    events_watcher = EventsWatcher(events_handler)
-
-    # did we already see the execution status change, and are only waiting
-    # for additional logs now?
-    waiting_for_logs = False
 
     while True:
         if timeout is not None:
@@ -309,29 +249,11 @@ def wait_for_execution_group(client,
             group_finished = execution_group.status in Execution.END_STATES
 
         events_fetcher.fetch_and_process_events(
-            events_handler=events_watcher, timeout=timeout)
+            events_handler=events_handler, timeout=timeout)
 
-        if group_finished and \
-                events_watcher.end_logs_received >= execution_amount:
+        if group_finished:
             break
 
-        # if the execution ended, wait one iteration for additional logs
-        sleep_interval = WAIT_FOR_EXECUTION_SLEEP_INTERVAL
-        if group_finished:
-            if waiting_for_logs:
-                if logger:
-                    logger.info('Execution ended, but no end log message '
-                                'received. Some logs might not have been '
-                                'displayed.')
-                break
-            else:
-                sleep_interval = WAIT_FOR_LAST_MESSAGES_SLEEP_INTERVAL
-                if logger:
-                    logger.info('Execution ended, waiting {0} seconds for '
-                                'additional log messages'
-                                .format(sleep_interval))
-                waiting_for_logs = True
-
-        time.sleep(sleep_interval)
+        time.sleep(WAIT_FOR_EXECUTION_SLEEP_INTERVAL)
 
     return execution_group
