@@ -34,11 +34,12 @@ from backports.shutil_get_terminal_size import get_terminal_size
 
 import yaml
 import requests
+from retrying import retry
 
 from .logger import get_logger, get_events_logger
 from .exceptions import CloudifyCliError, CloudifyTimeoutError
 from .constants import SUPPORTED_ARCHIVE_TYPES, DEFAULT_TIMEOUT
-from .execution_events_fetcher import ExecutionEventsFetcher, EventsWatcher
+from .execution_events_fetcher import ExecutionEventsFetcher
 
 from cloudify._compat import urlparse
 from cloudify.models_states import BlueprintUploadState
@@ -425,7 +426,21 @@ def wait_for_blueprint_upload(client, blueprint_id, logging_level):
                     blueprint['error_traceback'])
             raise CloudifyCliError(error_msg)
 
-    blueprint = client.blueprints.get(blueprint_id)
+    @retry(stop_max_attempt_number=5, wait_fixed=1000)
+    def _get_blueprint_and_upload_execution_id():
+        bp = client.blueprints.get(blueprint_id)
+        # upload_execution['id'] might not be available at first, hence retry
+        return bp, bp.upload_execution['id']
+
+    try:
+        blueprint, execution_id = _get_blueprint_and_upload_execution_id()
+    except KeyError:
+        raise RuntimeError(
+            'Failed to get upload_blueprint workflow execution for blueprint '
+            '{0}.  That may indicate a problem with blueprint upload.  Verify '
+            'blueprint\'s state by running command `cfy blueprints get {0}`.'
+            .format(blueprint_id)
+        )
 
     # if blueprint upload already ended - return without waiting
     if blueprint['state'] in BlueprintUploadState.END_STATES:
@@ -434,17 +449,13 @@ def wait_for_blueprint_upload(client, blueprint_id, logging_level):
 
     deadline = time.time() + DEFAULT_TIMEOUT
 
-    execution = [
-        ex for ex in client.executions.list(workflow_id='upload_blueprint')
-        if ex['parameters']['blueprint_id'] == blueprint_id
-    ][-1]   # is there are several matching executions, we want the latest
     events_fetcher = ExecutionEventsFetcher(
-        client, execution_id=execution.id, include_logs=True)
+        client, execution_id=execution_id, include_logs=True)
 
     # Poll for execution status and execution logs, until execution ends
     # and we receive an event of type in WORKFLOW_END_TYPES
     upload_ended = False
-    events_watcher = EventsWatcher(get_events_logger(None))
+    events_handler = get_events_logger(None)
 
     # Poll for blueprint upload status, until the upload ends
     while True:
@@ -459,9 +470,9 @@ def wait_for_blueprint_upload(client, blueprint_id, logging_level):
                 blueprint['state'] in BlueprintUploadState.END_STATES
 
         events_fetcher.fetch_and_process_events(
-            events_handler=events_watcher, timeout=timeout)
+            events_handler=events_handler, timeout=timeout)
 
-        if upload_ended and events_watcher.end_logs_received > 0:
+        if upload_ended:
             break
 
         time.sleep(WAIT_FOR_BLUEPRINT_UPLOAD_SLEEP_INTERVAL)
